Learn R Programming

CityWaterBalance (version 0.1.0)

combineWaterUse: Combine water use data for urban system into functional flows

Description

This function takes county-level USGS water use data gathered by getWaterUse and aggregates them for whole urban system according to flows in CityWaterBalance

Usage

combineWaterUse(start, end, wu)

Arguments

start

start date in format 'YYYY-MM-DD'

end

end date in format 'YYYY-MM-DD'

wu

list of dataframes output by getWaterUse

Value

wu_flows list of xts objects aggregating water withdrawals (MGal) by:

sw_ind

surface water for industrial use

sw_pot

surface water for potable use

sw_npot

surface water for nonpotable use

gw_ind

groundwater for industrial use

gw_pot

groundwater for potable use

gw_npot

groundwater for nonpotable use

Examples

Run this code

wu <- getWaterUse(c('IL'), c('Cook', 'Lake'))
wu_flows <- combineWaterUse('2000-01-01', '2015-01-01', wu)

Run the code above in your browser using DataLab